from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class DrfpasswordlessConfig(AppConfig):
    name = 'drfpasswordless'
    verbose = _("DRF Passwordless")

    def ready(self):
        import drfpasswordless.signals



# Generated by Django 2.2.9 on 2020-01-22 04:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfpasswordless', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='callbacktoken',
            name='to_alias',
            field=models.CharField(blank=True, max_length=254),
        ),
    ]



from django.utils.module_loading import import_string
from drfpasswordless.settings import api_settings
from drfpasswordless.utils import (
    create_callback_token_for_user,
)


class TokenService(object):
    @staticmethod
    def send_token(user, alias_type, token_type, to_alias=None, **message_payload):
        token = create_callback_token_for_user(user, alias_type, token_type, to_alias)
        send_action = None

        if user.pk in api_settings.PASSWORDLESS_DEMO_USERS.keys():
            return True
        if alias_type == 'email':
            send_action = import_string(api_settings.PASSWORDLESS_EMAIL_CALLBACK)
            if not to_alias:
                to_alias = getattr(
                    user, api_settings.PASSWORDLESS_USER_EMAIL_FIELD_NAME
                )

        elif alias_type == 'mobile':
            send_action = import_string(api_settings.PASSWORDLESS_SMS_CALLBACK)
            if not to_alias:
                to_alias = getattr(
                    user, api_settings.PASSWORDLESS_USER_MOBILE_FIELD_NAME
                )

        # Send to alias
        success = send_action(user, to_alias, token, **message_payload)
        return success



from django.conf import settings
from rest_framework.settings import APISettings

USER_SETTINGS = getattr(settings, 'PASSWORDLESS_AUTH', None)

DEFAULTS = {
    # --- MANDATORY SETTINGS --- #
    # The email the callback token is sent from
    'PASSWORDLESS_EMAIL_NOREPLY_ADDRESS': None,

    # Your twilio number that sends the callback tokens.
    'PASSWORDLESS_MOBILE_NOREPLY_NUMBER': None,

    # --- GENERAL SETTINGS --- #

    # Allowed to choose custom user model
    'PASSWORDLESS_USER_MODEL': None,
    # Allowed auth types, can be EMAIL, MOBILE, or both.
    'PASSWORDLESS_AUTH_TYPES': ['EMAIL', 'MOBILE'],

    # URL Prefix for Authentication Endpoints
    'PASSWORDLESS_AUTH_PREFIX': 'auth/',

    #  URL Prefix for Verification Endpoints
    'PASSWORDLESS_VERIFY_PREFIX': 'auth/verify/',

    #  URL Prefix for Change Endpoints
    'PASSWORDLESS_CHANGE_PREFIX': 'auth/change/',

    # Amount of time that tokens last, in seconds
    'PASSWORDLESS_TOKEN_EXPIRE_TIME': 15 * 60,

    # The user's email field name
    'PASSWORDLESS_USER_EMAIL_FIELD_NAME': 'email',

    # The user's mobile field name
    'PASSWORDLESS_USER_MOBILE_FIELD_NAME': 'mobile',

    # Marks itself as verified the first time a user completes auth via token.
    # Automatically unmarks itself if email is changed.
    'PASSWORDLESS_USER_MARK_EMAIL_VERIFIED': False,
    'PASSWORDLESS_USER_EMAIL_VERIFIED_FIELD_NAME': 'email_verified',

    # Marks itself as verified the first time a user completes auth via token.
    # Automatically unmarks itself if mobile number is changed.
    'PASSWORDLESS_USER_MARK_MOBILE_VERIFIED': False,
    'PASSWORDLESS_USER_MOBILE_VERIFIED_FIELD_NAME': 'mobile_verified',

    # Configurable token length.
    'PASSWORDLESS_CALLBACK_TOKEN_LENGTH': 6,

    # Token Generation Retry Count
    'PASSWORDLESS_TOKEN_GENERATION_ATTEMPTS': 3,

    # Automatically send verification email or sms when a user changes their alias.
    'PASSWORDLESS_AUTO_SEND_VERIFICATION_TOKEN': False,

    # Registers previously unseen aliases as new users.
    'PASSWORDLESS_REGISTER_NEW_USERS': True,

    # Context Processors for Email Template
    'PASSWORDLESS_CONTEXT_PROCESSORS': [],

    # Standardise mobile number before validation
    'PASSWORDLESS_MOBILE_NUMBER_STANDARDISE': False,

    # --- MESSAGES SECTION --- #

    # LOGIN MESSAGES
    # The email subject
    'PASSWORDLESS_EMAIL_SUBJECT': "Your Login Token",
    # A plaintext email message overridden by the html message. Takes one string.
    'PASSWORDLESS_EMAIL_PLAINTEXT_MESSAGE': "Enter this token to sign in: %s",
    # The email template name.
    'PASSWORDLESS_EMAIL_TOKEN_HTML_TEMPLATE_NAME': "passwordless_default_token_email.html",

    # The message sent to mobile users logging in. Takes one string.
    'PASSWORDLESS_MOBILE_MESSAGE': "Use this code to log in: %s",

    # VERIFICATION MESSAGES
    # The verification email subject
    'PASSWORDLESS_EMAIL_VERIFICATION_SUBJECT': "Your Verification Token",
    # A plaintext verification email message overridden by the html message. Takes one string.
    'PASSWORDLESS_EMAIL_VERIFICATION_PLAINTEXT_MESSAGE': "Enter this verification code: %s",
    # The verification email template name.
    'PASSWORDLESS_EMAIL_VERIFICATION_TOKEN_HTML_TEMPLATE_NAME': "passwordless_default_verification_token_email.html",

    # The message sent to mobile users verification. Takes one string.
    'PASSWORDLESS_MOBILE_VERIFICATION_MESSAGE': "Enter this verification code: %s",

    # CHANGE MESSAGES
    # The change email subject
    'PASSWORDLESS_EMAIL_CHANGE_SUBJECT': "Your Verification Token",
    # A plaintext change email message overridden by the html message. Takes one string.
    'PASSWORDLESS_EMAIL_CHANGE_PLAINTEXT_MESSAGE': "Enter this verification code: %s",
    # The change email template name.
    'PASSWORDLESS_EMAIL_CHANGE_TOKEN_HTML_TEMPLATE_NAME': "passwordless_default_change_token_email.html",

    # The message sent to mobile users verification. Takes one string.
    'PASSWORDLESS_MOBILE_CHANGE_MESSAGE': "Enter this verification code: %s",

    # --- TESTING SETTINGS --- #

    # Suppresses actual SMS for testing
    'PASSWORDLESS_TEST_SUPPRESSION': False,

    # Testing mode (every token applicable)
    'PASSWORDLESS_TEST_MODE': False,

    # List with incorrect codes (integer, please) for the test mode.
    'PASSWORDLESS_TEST_CODE_INCORRECT': [],

    # A dictionary of demo user's primary key mapped to their static pin
    'PASSWORDLESS_DEMO_USERS': {},

    # --- ADVANCED SETTINGS --- #

    # What function is called to construct an authentication tokens when
    # exchanging a passwordless token for a real user auth token.
    'PASSWORDLESS_AUTH_TOKEN_CREATOR': 'drfpasswordless.utils.create_authentication_token',

    # What function is called to construct a serializer for drf tokens when
    # exchanging a passwordless token for a real user auth token.
    'PASSWORDLESS_AUTH_TOKEN_SERIALIZER': 'drfpasswordless.serializers.TokenResponseSerializer',

    'PASSWORDLESS_EMAIL_CALLBACK': 'drfpasswordless.utils.send_email_with_callback_token',
    'PASSWORDLESS_SMS_CALLBACK': 'drfpasswordless.utils.send_sms_with_callback_token',
}

# List of settings that may be in string import notation.
IMPORT_STRINGS = (
    'PASSWORDLESS_EMAIL_TOKEN_HTML_TEMPLATE',
    'PASSWORDLESS_CONTEXT_PROCESSORS',
)

api_settings = APISettings(USER_SETTINGS, DEFAULTS, IMPORT_STRINGS)



# -*- coding: utf-8 -*-

__title__ = 'drfpasswordless'
__version__ = '1.1.3'
__author__ = 'Aaron Ng'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022 Aaron Ng'

# Version synonym
VERSION = __version__

default_app_config = 'drfpasswordless.apps.DrfpasswordlessConfig'



from drfpasswordless.settings import api_settings
from django.urls import path
from drfpasswordless.views import (
    ObtainEmailCallbackToken,
    ObtainMobileCallbackToken,
    ObtainEmailVerificationCallbackToken,
    ObtainMobileVerificationCallbackToken,
    ObtainEmailChangeCallbackToken,
    ObtainMobileChangeCallbackToken,
    ObtainAuthTokenFromCallbackToken,
    VerifyAliasFromCallbackToken,
    ChangeAliasFromCallbackToken,
)

app_name = 'drfpasswordless'

urlpatterns = [
    path(api_settings.PASSWORDLESS_AUTH_PREFIX + 'email/',
         ObtainEmailCallbackToken.as_view(), name='auth_email'),
    path(api_settings.PASSWORDLESS_AUTH_PREFIX + 'mobile/',
         ObtainMobileCallbackToken.as_view(), name='auth_mobile'),
    path(api_settings.PASSWORDLESS_AUTH_PREFIX + 'token/',
         ObtainAuthTokenFromCallbackToken.as_view(), name='auth_token'),
    path(api_settings.PASSWORDLESS_VERIFY_PREFIX + 'email/',
         ObtainEmailVerificationCallbackToken.as_view(), name='verify_email'),
    path(api_settings.PASSWORDLESS_VERIFY_PREFIX + 'mobile/',
         ObtainMobileVerificationCallbackToken.as_view(), name='verify_mobile'),
    path(api_settings.PASSWORDLESS_VERIFY_PREFIX,
         VerifyAliasFromCallbackToken.as_view(), name='verify_token'),
    path(api_settings.PASSWORDLESS_CHANGE_PREFIX + 'email/',
         ObtainEmailChangeCallbackToken.as_view(), name='change_email'),
    path(api_settings.PASSWORDLESS_CHANGE_PREFIX + 'mobile/',
         ObtainMobileChangeCallbackToken.as_view(), name='change_mobile'),
    path(api_settings.PASSWORDLESS_CHANGE_PREFIX,
         ChangeAliasFromCallbackToken.as_view(), name='change_token'),
]



# Generated by Django 3.0.2 on 2020-11-17 04:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('drfpasswordless', '0004_auto_20200125_0853'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='callbacktoken',
            unique_together=set(),
        ),
    ]



import logging
from django.utils.module_loading import import_string
from rest_framework import status
from rest_framework.response import Response
from rest_framework.permissions import AllowAny, IsAuthenticated
from rest_framework.views import APIView
from drfpasswordless.models import CallbackToken
from drfpasswordless.settings import api_settings
from drfpasswordless.serializers import (
    EmailAuthSerializer,
    MobileAuthSerializer,
    EmailVerificationSerializer,
    MobileVerificationSerializer,
    EmailChangeSerializer,
    MobileChangeSerializer,
    CallbackTokenAuthSerializer,
    CallbackTokenVerificationSerializer,
    CallbackTokenChangeSerializer,
)
from drfpasswordless.services import TokenService

logger = logging.getLogger(__name__)

# TODO: separate views to different files.

"""
Abstract Obtain Callback tokens
"""


class AbstractBaseObtainCallbackToken(APIView):
    """
    This returns a 6-digit callback token we can trade for a user's Auth Token.
    """
    success_response = "A login token has been sent to you."
    failure_response = "Unable to send you a login code. Try again later."

    message_payload = {}

    @property
    def serializer_class(self):
        # Our serializer depending on type
        raise NotImplementedError

    @property
    def alias_type(self):
        # Alias Type
        raise NotImplementedError

    @property
    def token_type(self):
        # Token Type
        raise NotImplementedError

    def post(self, request, *args, **kwargs):
        if self.alias_type.upper() not in api_settings.PASSWORDLESS_AUTH_TYPES:
            # Only allow auth types allowed in settings.
            logger.debug('Not allowed auth type in settings.')
            return Response(status=status.HTTP_404_NOT_FOUND)

        serializer = self.serializer_class(data=request.data,
                                           context={'request': request})
        if serializer.is_valid(raise_exception=True):
            # Validate -
            user = serializer.validated_data['user']
            # Create and send callback token
            success = TokenService.send_token(user, self.alias_type, self.token_type,
                                              **self.message_payload)

            # Respond With Success Or Failure of Sent
            if success:
                status_code = status.HTTP_200_OK
                response_detail = self.success_response
            else:
                status_code = status.HTTP_400_BAD_REQUEST
                response_detail = self.failure_response
            return Response({'detail': response_detail}, status=status_code)
        else:
            return Response(serializer.error_messages,
                            status=status.HTTP_400_BAD_REQUEST)


class AbstractChangeCallbackToken(AbstractBaseObtainCallbackToken):
    def post(self, request, *args, **kwargs):
        if self.alias_type.upper() not in api_settings.PASSWORDLESS_AUTH_TYPES:
            # Only allow auth types allowed in settings.
            logger.debug('Not allowed auth type in settings.')
            return Response(status=status.HTTP_404_NOT_FOUND)

        serializer = self.serializer_class(data=request.data,
                                           context={'request': request})
        if serializer.is_valid(raise_exception=True):
            # Validate -
            user = serializer.validated_data['user']
            # Create and send callback token
            success = TokenService.send_token(
                user,
                self.alias_type,
                self.token_type,
                serializer.validated_data['mobile'],
                **self.message_payload,
            )

            # Respond With Success Or Failure of Sent
            if success:
                status_code = status.HTTP_200_OK
                response_detail = self.success_response
            else:
                status_code = status.HTTP_400_BAD_REQUEST
                response_detail = self.failure_response
            return Response({'detail': response_detail}, status=status_code)
        else:
            return Response(serializer.error_messages,
                            status=status.HTTP_400_BAD_REQUEST)


"""
Login Obtain Callback tokens
"""


class ObtainEmailCallbackToken(AbstractBaseObtainCallbackToken):
    """
    Send token to user by e-mail.

    Receive: email
    Response: message or detail
    This returns a 6-digit callback token we can trade for a user's Auth Token.
    """
    permission_classes = (AllowAny,)
    serializer_class = EmailAuthSerializer
    success_response = "A login token has been sent to your email."
    failure_response = "Unable to email you a login code. Try again later."

    alias_type = 'email'
    token_type = CallbackToken.TOKEN_TYPE_AUTH

    email_subject = api_settings.PASSWORDLESS_EMAIL_SUBJECT
    email_plaintext = api_settings.PASSWORDLESS_EMAIL_PLAINTEXT_MESSAGE
    email_html = api_settings.PASSWORDLESS_EMAIL_TOKEN_HTML_TEMPLATE_NAME
    message_payload = {'email_subject': email_subject,
                       'email_plaintext': email_plaintext,
                       'email_html': email_html}


class ObtainMobileCallbackToken(AbstractBaseObtainCallbackToken):
    """
    Send token to user by SMS.

    Receive: mobile
    Response: message or detail
    This returns a 6-digit callback token we can trade for a user's Auth Token.
    """
    permission_classes = (AllowAny,)
    serializer_class = MobileAuthSerializer
    success_response = "We texted you a login code."
    failure_response = "Unable to send you a login code. Try again later."

    alias_type = 'mobile'
    token_type = CallbackToken.TOKEN_TYPE_AUTH

    mobile_message = api_settings.PASSWORDLESS_MOBILE_MESSAGE
    message_payload = {'mobile_message': mobile_message}


"""
Verification Obtain Callback tokens
"""


class ObtainEmailVerificationCallbackToken(AbstractBaseObtainCallbackToken):
    """
    Send token to user by e-mail for verification.

    Receive: Nothing
    Response: message or detail
    This returns a 6-digit callback token we can trade for a user's Auth Token.
    """
    permission_classes = (IsAuthenticated,)
    serializer_class = EmailVerificationSerializer
    success_response = "A verification token has been sent to your email."
    failure_response = "Unable to email you a verification code. Try again later."

    alias_type = 'email'
    token_type = CallbackToken.TOKEN_TYPE_VERIFY

    email_subject = api_settings.PASSWORDLESS_EMAIL_VERIFICATION_SUBJECT
    email_plaintext = api_settings.PASSWORDLESS_EMAIL_VERIFICATION_PLAINTEXT_MESSAGE
    email_html = api_settings.PASSWORDLESS_EMAIL_VERIFICATION_TOKEN_HTML_TEMPLATE_NAME
    message_payload = {
        'email_subject': email_subject,
        'email_plaintext': email_plaintext,
        'email_html': email_html
    }


class ObtainMobileVerificationCallbackToken(AbstractBaseObtainCallbackToken):
    """
    Send token to user by SMS for verification.

    Receive: Nothing
    Response: message or detail
    This returns a 6-digit callback token we can trade for a user's Auth Token.
    """
    permission_classes = (IsAuthenticated,)
    serializer_class = MobileVerificationSerializer
    success_response = "We texted you a verification code."
    failure_response = "Unable to send you a verification code. Try again later."

    alias_type = 'mobile'
    token_type = CallbackToken.TOKEN_TYPE_VERIFY

    mobile_message = api_settings.PASSWORDLESS_MOBILE_VERIFICATION_MESSAGE
    message_payload = {'mobile_message': mobile_message}


"""
Change Obtain Callback tokens
"""


class ObtainEmailChangeCallbackToken(AbstractChangeCallbackToken):
    """
    Send token to user by e-mail for changing.

    Receive: email
    Response: message or detail
    This returns a 6-digit callback token we can trade for a user's Auth Token.
    """
    permission_classes = (IsAuthenticated,)
    serializer_class = EmailChangeSerializer
    success_response = "A verification token has been sent to your email."
    failure_response = "Unable to email you a verification code. Try again later."

    alias_type = 'email'
    token_type = CallbackToken.TOKEN_TYPE_CHANGE

    email_subject = api_settings.PASSWORDLESS_EMAIL_VERIFICATION_SUBJECT
    email_plaintext = api_settings.PASSWORDLESS_EMAIL_VERIFICATION_PLAINTEXT_MESSAGE
    email_html = api_settings.PASSWORDLESS_EMAIL_VERIFICATION_TOKEN_HTML_TEMPLATE_NAME
    message_payload = {
        'email_subject': email_subject,
        'email_plaintext': email_plaintext,
        'email_html': email_html
    }


class ObtainMobileChangeCallbackToken(AbstractChangeCallbackToken):
    """
    Send token to user by SMS for changing.

    Receive: mobile
    Response: message or detail
    This returns a 6-digit callback token we can trade for a user's Auth Token.
    """
    permission_classes = (IsAuthenticated,)
    serializer_class = MobileChangeSerializer
    success_response = "We texted you a verification code."
    failure_response = "Unable to send you a verification code. Try again later."

    alias_type = 'mobile'
    token_type = CallbackToken.TOKEN_TYPE_CHANGE

    mobile_message = api_settings.PASSWORDLESS_MOBILE_CHANGE_MESSAGE
    message_payload = {'mobile_message': mobile_message}


"""
Obtain Auth tokens
"""


class AbstractBaseObtainAuthToken(APIView):
    """
    This is a duplicate of rest_framework's own ObtainAuthToken method.
    Instead, this returns an Auth Token based on our 6 digit callback token and source.
    """
    serializer_class = None

    def post(self, request, *args, **kwargs):
        serializer = self.serializer_class(data=request.data)
        if serializer.is_valid(raise_exception=True):
            user = serializer.validated_data['user']
            token_creator = import_string(api_settings.PASSWORDLESS_AUTH_TOKEN_CREATOR)
            (token, _) = token_creator(user)

            if token:
                TokenSerializer = import_string(
                    api_settings.PASSWORDLESS_AUTH_TOKEN_SERIALIZER)
                token_serializer = TokenSerializer(data=token.__dict__, partial=True)
                if token_serializer.is_valid():
                    # Return our key for consumption.
                    return Response(token_serializer.data, status=status.HTTP_200_OK)
        else:
            logger.error(
                "Couldn't log in unknown user. Errors on serializer: {}".format(
                    serializer.error_messages))
        return Response({'detail': 'Couldn\'t log you in. Try again later.'},
                        status=status.HTTP_400_BAD_REQUEST)


class ObtainAuthTokenFromCallbackToken(AbstractBaseObtainAuthToken):
    """
    Verify token received from user for login/registration purpose.

    Receive: email or mobile, token
    Response: token
    This is a duplicate of rest_framework's own ObtainAuthToken method.
    Instead, this returns an Auth Token based on our callback token and source.
    """
    permission_classes = (AllowAny,)
    serializer_class = CallbackTokenAuthSerializer


class VerifyAliasFromCallbackToken(APIView):
    """
    Verify token received from user and verify alias.

    Receive: email or mobile, token
    Response: message
    This verifies an alias on correct callback token entry using the same logic as auth.
    Should be refactored at some point.
    """
    serializer_class = CallbackTokenVerificationSerializer

    def post(self, request, *args, **kwargs):
        serializer = self.serializer_class(data=request.data,
                                           context={'user_id': self.request.user.id})
        if serializer.is_valid(raise_exception=True):
            return Response({'detail': 'Alias verified.'}, status=status.HTTP_200_OK)
        else:
            logger.error(
                "Couldn't verify unknown user. Errors on serializer: {}".format(
                    serializer.error_messages))

        return Response({'detail': 'We couldn\'t verify this alias. Try again later.'},
                        status.HTTP_400_BAD_REQUEST)


class ChangeAliasFromCallbackToken(APIView):
    """
    Verify token received from user and change alias.

    Receive: email or mobile, token
    Response: message
    This verifies an alias on correct callback token entry using the same logic as auth.
    Should be refactored at some point.
    """
    serializer_class = CallbackTokenChangeSerializer

    def post(self, request, *args, **kwargs):
        serializer = self.serializer_class(
            data=request.data,
            context={'user_id': self.request.user.id}
        )
        if serializer.is_valid(raise_exception=True):
            return Response({'detail': 'Alias changed.'}, status=status.HTTP_200_OK)
        else:
            logger.error(
                "Couldn't change unknown user. Errors on serializer: {}".format(
                    serializer.error_messages))

        return Response({'detail': 'We couldn\'t change this alias. Try again later.'},
                        status.HTTP_400_BAD_REQUEST)



# Generated by Django 4.2.8 on 2024-02-14 11:27
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion

from drfpasswordless.settings import api_settings

if api_settings.PASSWORDLESS_USER_MODEL:
    USER_MODEL = api_settings.PASSWORDLESS_USER_MODEL
else:
    USER_MODEL = settings.AUTH_USER_MODEL


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(USER_MODEL),
        ("drfpasswordless", "0007_alter_callbacktoken_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="callbacktoken",
            name="user",
            field= models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=USER_MODEL),
        ),
    ]



# Generated by Django 3.0.2 on 2020-01-22 08:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfpasswordless', '0002_auto_20200122_0424'),
    ]

    operations = [
        migrations.AddField(
            model_name='callbacktoken',
            name='type',
            field=models.CharField(choices=[('AUTH', 'Auth'), ('VERIFY', 'Verify')], default='VERIFY', max_length=20),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-05 03:27
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import drfpasswordless.models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='CallbackToken',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('is_active', models.BooleanField(default=True)),
                ('to_alias', models.CharField(blank=True, max_length=40)),
                ('to_alias_type', models.CharField(blank=True, max_length=20)),
                ('key', models.CharField(default=drfpasswordless.models.generate_numeric_token, max_length=6, unique=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Callback Token',
                'abstract': False,
                'ordering': ['-id'],
                'get_latest_by': 'created_at',
            },
        ),
        migrations.AlterUniqueTogether(
            name='callbacktoken',
            unique_together=set([('key', 'is_active')]),
        ),
    ]



# Generated by Django 3.1.14 on 2022-12-28 13:53

from django.db import migrations, models
import drfpasswordless.models


class Migration(migrations.Migration):

    dependencies = [
        ('drfpasswordless', '0005_auto_20201117_0410'),
    ]

    operations = [
        migrations.AlterField(
            model_name='callbacktoken',
            name='key',
            field=models.TextField(default=drfpasswordless.models.generate_numeric_token),
        ),
    ]
